You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@commons.apache.org by sg...@apache.org on 2012/02/18 22:22:19 UTC

svn commit: r1290877 - /commons/proper/email/trunk/src/java/org/apache/commons/mail/Email.java

Author: sgoeschl
Date: Sat Feb 18 21:22:19 2012
New Revision: 1290877

URL: http://svn.apache.org/viewvc?rev=1290877&view=rev
Log:
[EMAIL-111] Providing binary compatibility for setter (second part of patch)

Modified:
    commons/proper/email/trunk/src/java/org/apache/commons/mail/Email.java

Modified: commons/proper/email/trunk/src/java/org/apache/commons/mail/Email.java
URL: http://svn.apache.org/viewvc/commons/proper/email/trunk/src/java/org/apache/commons/mail/Email.java?rev=1290877&r1=1290876&r2=1290877&view=diff
==============================================================================
--- commons/proper/email/trunk/src/java/org/apache/commons/mail/Email.java (original)
+++ commons/proper/email/trunk/src/java/org/apache/commons/mail/Email.java Sat Feb 18 21:22:19 2012
@@ -191,7 +191,6 @@ public abstract class Email implements E
      * Setting to true will enable the display of debug information.
      *
      * @param d A boolean.
-     * @return An Email.
      * @since 1.0
      */
     public void setDebug(boolean d)
@@ -208,7 +207,6 @@ public abstract class Email implements E
      *
      * @param userName User name for the SMTP server
      * @param password password for the SMTP server
-     * @return An Email.
      * @see DefaultAuthenticator
      * @see #setAuthenticator
      * @since 1.0
@@ -226,7 +224,6 @@ public abstract class Email implements E
      * authentication.  Your mail server must also support RFC2554.
      *
      * @param newAuthenticator the <code>Authenticator</code> object.
-     * @return Email.
      * @see Authenticator
      * @since 1.0
      */
@@ -345,12 +342,12 @@ public abstract class Email implements E
      * for the reasons of deprecation.
      *
      * @deprecated since 1.3, use setStartTLSEnabled() instead
      * @param startTlsEnabled true if STARTTLS requested, false otherwise
      * @since 1.1
      */
     public void setTLS(boolean withTLS)
     {
-        setStartTLSEnabled(startTlsEnabled);
+        setStartTLSEnabled(withTLS);
     }
 
     /**
@@ -345,12 +342,12 @@ public abstract class Email implements E
      *
      * @deprecated since 1.3, use setStartTLSEnabled() instead
-     * @param startTlsEnabled true if STARTTLS requested, false otherwise
+     * @param withTLS true if STARTTLS requested, false otherwise
      * @since 1.1
      */